@@ -38,6 +38,9 @@ FAILEDOPERATION_FLOWHASNODOCUMENT = 'FailedOperation.FlowHasNoDocument'
 # 签署审核未通过，请先完成审核。
 FAILEDOPERATION_NOSIGNREVIEWPASS = 'FailedOperation.NoSignReviewPass'
 
+# 未找到集团子企业相关用户信息，请检查用户相关参数
+FAILEDOPERATION_NOTFOUNDSHADOWUSER = 'FailedOperation.NotFoundShadowUser'
+
 # 企业经营状态与工商局信息不符。
 FAILEDOPERATION_ORGANIZATIONEXPERIENCECHANGE = 'FailedOperation.OrganizationExperienceChange'
 
@@ -500,6 +503,9 @@ OPERATIONDENIED_SERVERSIGNNOALLOWCOMPONENT = 'OperationDenied.ServerSignNoAllowC
 # 静默签署不支持手写签名，请配置印章并使用印章重试。
 OPERATIONDENIED_SERVERSIGNNOSUPPORTSIGNATURE = 'OperationDenied.ServerSignNoSupportSignature'
 
+# 子企业暂未加入。
+OPERATIONDENIED_SUBORGNOTJOIN = 'OperationDenied.SubOrgNotJoin'
+
 # 用户不归属于当前企业，无法操作，请检查后重试。
 OPERATIONDENIED_USERNOTINORGANIZATION = 'OperationDenied.UserNotInOrganization'
 
